/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace BoxEdit3D
{
    /// <summary>
    /// Base class for all the commands used in the command history. The command
    /// classes follow the Command design pattern defined by Gamma et. al.
    /// </summary>
    abstract class Command
    {
        /// <summary>
        /// Holds the box on which to execute the command.
        /// </summary>
        protected Box m_box;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="box">The box on which this command will be executed.</param>
        protected Command(Box box)
        {
            m_box = box;
        }

        /// <summary>
        /// Execute the command on the box.
        /// </summary>
        public abstract void execute();

        /// <summary>
        /// Undo the execution of the command on the box.
        /// </summary>
        public abstract void unexecute();
    }
}
