/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

float4x4 g_worldViewProj;
float g_numberOfLines;

struct VertexShaderInput
{
    float4 Position : POSITION0;
	float2 TexCoords : TEXCOORD0;
};

struct VertexShaderOutput
{
    float4 Position : POSITION0;
	float2 TexCoords : TEXCOORD0;
};

struct PixelShaderInput
{
 	float2 TexCoords : TEXCOORD0;
};

VertexShaderOutput VertexShaderFunction(VertexShaderInput input)
{
    VertexShaderOutput output;

    output.Position = mul(input.Position, g_worldViewProj);
	output.TexCoords = input.TexCoords;

    return output;
}

float4 PixelShaderFunction(PixelShaderInput input) : COLOR0
{
	float2 rest = frac(input.TexCoords / ( 1.0f / g_numberOfLines));
	if (rest.x > 0.5f) rest.x = 1.0f - rest.x;
	if (rest.y > 0.5f) rest.y = 1.0f - rest.y;
	float dist = min(rest.x, rest.y);
	float intensity = 1.0f - (dist * 8.0f);
	float alpha = max(intensity, 0.35f);
	return float4(intensity, 0.0f, 0.0f, alpha);
}

technique Technique1
{
    pass P1
    {
        VertexShader = compile vs_2_0 VertexShaderFunction();
        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}
