/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;

namespace BoxEdit3D
{
    /// <summary>
    /// This class is a derived class of the command class. It handles
    /// the translation of boxes. An instance of this class will be 
    /// issued every time a box is translated. This class is part of
    /// the command design pattern published by Gamma et. al.
    /// </summary>
    class TranslateCommand : Command
    {
        /// <summary>
        /// The translation that will be applied by the TranslationCommand.
        /// </summary>
        private Vector3 m_translation;

        /// <summary>
        /// The absolute translation of the box before the new translation was applied.
        /// </summary>
        private Vector3 m_oldTranslation;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="box">The box on which this command will be executed.</param>
        /// <param name="translation">The translation that will be applied to the box by this command.</param>
        public TranslateCommand(Box box, Vector3 translation)
            : base(box)
        {
            m_translation = translation;
            m_oldTranslation = m_box.getTranslation();
        }

        /// <summary>
        /// Execute the command on the box.
        /// </summary>
        public override void execute()
        {
            m_box.setTranslation(m_translation);
        }

        /// <summary>
        /// Undo the execution of the command on the box.
        /// </summary>
        public override void unexecute()
        {
            m_box.setTranslation(m_oldTranslation);
        }
    }
}
